@@ -31,8 +31,20 @@ class SubGit():
 
     def __init__(self, config_file_path=None, answer_yes=False):
         self.answer_yes = answer_yes
+        self.config_file_path = config_file_path
 
-        if not config_file_path:
+        if config_file_path:
+            self.subgit_config_file_name = Path(config_file_path).name
+            self.subgit_config_file_path = Path(config_file_path).resolve()
+        else:
+            self.subgit_config_file_name = ".subgit.yml"
+            self.subgit_config_file_path = Path.cwd() / ".subgit.yml"
+    
+    def _get_recursive_config_path(self):
+        """
+        Looks for either .sgit.yml or .subgit.yml recursively
+        """
+        if not self.config_file_path:
             # Get the CWD where you execute the script from
             path = Path().cwd()
 
@@ -65,8 +77,8 @@ class SubGit():
             log.debug(self.subgit_config_file_name)
             log.debug(self.subgit_config_file_path)
         else:
-            self.subgit_config_file_name = Path(config_file_path).name
-            self.subgit_config_file_path = Path(config_file_path).resolve()
+            self.subgit_config_file_name = Path(self.config_file_path).name
+            self.subgit_config_file_path = Path(self.config_file_path).resolve()
 
     def init_repo(self, repo_name=None, repo_url=None):
         """
@@ -74,6 +86,7 @@ class SubGit():
         .subgit.yml config file as the first repo in your config. If these values is anything else the initial
         config vill we written as empty.
         """
+
         if self.subgit_config_file_path.exists():
             log.error(f"File '{self.subgit_config_file_name}' already exists on disk")
             return 1
@@ -115,6 +128,7 @@ class SubGit():
             )
 
     def repo_status(self):
+        self._get_recursive_config_path()
         config = self._get_config_file()
         repos = config.get("repos", {})
 
@@ -244,6 +258,8 @@ class SubGit():
 
         A empty list of items will not fetch any repo.
         """
+        self._get_recursive_config_path()
+
         log.debug(f"repo fetch input - {repos}")
 
         config = self._get_config_file()
@@ -315,6 +331,8 @@ class SubGit():
 
         To pull a subset of repos send in a list of strings names=["repo1", "repo2"]
         """
+        self._get_recursive_config_path()
+
         log.debug(f"Repo pull - {names}")
 
         config = self._get_config_file()
@@ -408,9 +426,13 @@ class SubGit():
             repo_config = config["repos"][name]
             revision = repo_config["revision"]
 
+            # Boolean value wether repo is newly cloned.
+            cloned = False
+
             if not repo_path.exists():
                 clone_rev = revision["tag"] if "tag" in revision else revision["branch"]
                 clone_url = repo_config.get("url", None)
+                cloned = True
 
                 if not clone_url:
                     raise SubGitConfigException(f"Missing required key 'url' on repo '{name}'")
@@ -444,6 +466,16 @@ class SubGit():
                 # Extract the sub tag data
                 branch_revision = revision["branch"]
 
+                if not cloned:
+                    try:
+                        latest_remote_sha = str(repo.rev_parse(f"origin/{branch_revision}"))
+                        latest_local_sha = str(repo.head.commit.hexsha)
+
+                        if latest_remote_sha != latest_local_sha:
+                            repo.remotes.origin.pull()
+                    except git.exc.BadName as er:
+                        log.error(er)
+
                 # Ensure the local version of the branch exists and points to the origin ref for that branch
                 repo.create_head(f"{branch_revision}", f"origin/{branch_revision}")
 
@@ -554,6 +586,7 @@ class SubGit():
         more of them creates a conflict. (e.g repo(s) is not in the config file,
         path(s) is not to a valid git repo or repo(s) is dirty)
         """
+        self._get_recursive_config_path()
         has_dirty_repos = False
         good_repos = []
         repos_dict = self._get_repos(repo_names)
@@ -587,6 +620,7 @@ class SubGit():
         Will take a list of repos and find any diffs and reset them back
         to the same state they were when they were first pulled.
         """
+        self._get_recursive_config_path()
         dirty_repos = []
         repos_dict = self._get_repos(repo_names)
         repos = repos_dict["repos"]
@@ -626,6 +660,7 @@ class SubGit():
         """
         Method to look through a list of repos and remove untracked files
         """
+        self._get_recursive_config_path()
         dirty_repos = []
         recursive_flag = "d" if recurse_into_dir else ""
         force_flag = "f" if force else ""
